unit PrinterLib;

interface
function DemoPrinterCreator(model: ansistring): Integer;
function DemoPortOpen(ioSettings: ansistring): Integer;
function DemoPortClose(): Integer;
function DemoPrinterDestroy():Integer;
function AddLabel(offSet: Integer; height: Integer; qty: Integer): Integer;
function SetAlign(align: Integer): Integer;
function AddText(rotate: Integer; fontType: Integer; fontSize: Integer;
  xPos: Integer; yPos: Integer; data: ansistring ): Integer;
function AddBarCode(rotate: Integer; codetype: Integer; width: Integer;
  ratio: Integer; height: Integer; xPos: Integer; yPos: Integer;
  data: ansistring): Integer;
function AddBarCodeText(enable: Integer; fontType: Integer; fontSize: Integer;
  offSet: Integer): Integer;
function AddQRCode(rotate: Integer; xPos: Integer; yPos: Integer;
  model: Integer; unitWidth: Integer; eccLevel: Integer; data: ansistring): Integer;
function AddPDF417(rotate: Integer; xPos: Integer; yPos: Integer;
  xDots: Integer; yDots: Integer; columns: Integer; rows: Integer;
  eccLevel: Integer; data: ansistring): Integer;
function AddBox(xPos: Integer; yPos: Integer; endXPos: Integer;
  endYPos: Integer; thickness: Integer): Integer;
function AddLine(xPos: Integer; yPos: Integer; endXPos: Integer;
  endYPos: Integer; thickness: Integer): Integer;
function SetFontSize(width: Integer; height: Integer): Integer;
function SetDensity(density: Integer): Integer;
function SetSpeed(speed: Integer): Integer;
function SetTextSpacing(spacing: Integer): Integer;
function SetTextBold(bold: Integer): Integer;
function SetTextUnderline(underline: Integer): Integer;
function LabelPrint(): Integer;
function NextLabelPos(): Integer;
function PreFeed(distance: Integer): Integer;
function PostFeed(distance: Integer): Integer;

var
  // Error Code
  E_SUCCESS: Integer = 0;
  E_BAD_HANDLE: Integer = -6;
  // printer
  printer: Pointer;
  errorNo: Integer = 0;

implementation
function PrinterCreator(printer: PPointer; model: ansistring): Integer; stdcall;  external 'CPCL_SDK.dll';
function PrinterCreatorS(model: string): Pointer; stdcall;
  external 'CPCL_SDK.dll';
function PortOpen(printer: Pointer; ioSettings: ansistring): Integer; stdcall;
  external 'CPCL_SDK.dll';
function PortClose(printer: Pointer): Integer; stdcall; external 'CPCL_SDK.dll';
function PrinterDestroy(printer: Pointer): Integer; stdcall;
  external 'CPCL_SDK.dll';
function CPCL_AddLabel(printer: PPointer; offSet: Integer; height: Integer;
  qty: Integer): Integer; stdcall; external 'CPCL_SDK.dll';
function CPCL_SetAlign(printer: PPointer; align: Integer): Integer; stdcall;
  external 'CPCL_SDK.dll';
function CPCL_AddText(printer: PPointer; rotate: Integer; fontType: Integer;
  fontSize: Integer; xPos: Integer; yPos: Integer; data: ansistring): Integer;
  stdcall; external 'CPCL_SDK.dll';
function CPCL_AddBarCode(printer: PPointer; rotate: Integer; codetype: Integer;
  width: Integer; ratio: Integer; height: Integer; xPos: Integer; yPos: Integer;
  data: ansistring): Integer; stdcall; external 'CPCL_SDK.dll';
function CPCL_AddBarCodeText(printer: PPointer; enable: Integer;
  fontType: Integer; fontSize: Integer; offSet: Integer): Integer; stdcall;
  external 'CPCL_SDK.dll';
function CPCL_AddQRCode(printer: PPointer; rotate: Integer; xPos: Integer;
  yPos: Integer; model: Integer; unitWidth: Integer; eccLevel: Integer;
  data: ansistring): Integer; stdcall; external 'CPCL_SDK.dll';
function CPCL_AddPDF417(printer: PPointer; rotate: Integer; xPos: Integer;
  yPos: Integer; xDots: Integer; yDots: Integer; columns: Integer;
  rows: Integer; eccLevel: Integer; data: ansistring): Integer; stdcall;
  external 'CPCL_SDK.dll';
function CPCL_AddBox(printer: PPointer; xPos: Integer; yPos: Integer;
  endXPos: Integer; endYPos: Integer; thickness: Integer): Integer; stdcall;
  external 'CPCL_SDK.dll';
function CPCL_AddLine(printer: PPointer; xPos: Integer; yPos: Integer;
  endXPos: Integer; endYPos: Integer; thickness: Integer): Integer; stdcall;
  external 'CPCL_SDK.dll';
function CPCL_SetFontSize(printer: PPointer; width: Integer; height: Integer)
  : Integer; stdcall; external 'CPCL_SDK.dll';
function CPCL_SetDensity(printer: PPointer; density: Integer): Integer; stdcall;
  external 'CPCL_SDK.dll';
function CPCL_SetSpeed(printer: PPointer; speed: Integer): Integer; stdcall;
  external 'CPCL_SDK.dll';
function CPCL_SetTextSpacing(printer: PPointer; spacing: Integer): Integer;
  stdcall; external 'CPCL_SDK.dll';
function CPCL_SetTextBold(printer: PPointer; bold: Integer): Integer; stdcall;
  external 'CPCL_SDK.dll';
function CPCL_SetTextUnderline(printer: PPointer; underline: Integer): Integer;
  stdcall; external 'CPCL_SDK.dll';
function CPCL_Print(printer: PPointer): Integer; stdcall; external 'CPCL_SDK.dll';
function CPCL_NextLabelPos(printer: PPointer): Integer; stdcall;
  external 'CPCL_SDK.dll';
function CPCL_PreFeed(printer: PPointer; distance: Integer): Integer; stdcall;
  external 'CPCL_SDK.dll';
function CPCL_PostFeed(printer: PPointer; distance: Integer): Integer; stdcall;
  external 'CPCL_SDK.dll';



function DemoPrinterCreator(model: ansistring): Integer;
begin
  Result:= PrinterCreator(@printer, model);
end;

function DemoPrinterDestroy(): Integer;
begin
  Result:= PrinterDestroy(printer);
end;

function DemoPortOpen(ioSettings: ansistring): Integer;
begin
  Result:= PortOpen(printer, ioSettings);
end;

function DemoPortClose(): Integer;
begin
  Result:= PortClose(printer);
end;

function AddLabel(offSet: Integer; height: Integer; qty: Integer): Integer;
begin
  Result := CPCL_AddLabel(printer, offSet, height, qty);
end;

function SetAlign(align: Integer): Integer;
begin
  Result := CPCL_SetAlign(printer, align);
end;

function AddText(rotate: Integer; fontType: Integer; fontSize: Integer;
  xPos: Integer; yPos: Integer; data: ansistring ): Integer;
begin
  Result := CPCL_AddText(printer, rotate, fontType, fontSize, xPos,
    yPos, data);
end;

function AddBarCode(rotate: Integer; codetype: Integer; width: Integer;
  ratio: Integer; height: Integer; xPos: Integer; yPos: Integer;
  data: ansistring): Integer;
begin
  Result := CPCL_AddBarCode(printer, rotate, codetype, width, ratio, height,
    xPos, yPos, data);
end;

function AddQRCode(rotate: Integer; xPos: Integer; yPos: Integer;
  model: Integer; unitWidth: Integer; eccLevel: Integer; data: ansistring): Integer;
begin
  Result := CPCL_AddQRCode(printer, rotate, xPos, yPos, model, unitWidth,
    eccLevel, data);
end;

function AddBarCodeText(enable: Integer; fontType: Integer; fontSize: Integer;
  offSet: Integer): Integer;
begin
  Result := CPCL_AddBarCodeText(printer, enable, fontType, fontSize, offSet);
end;

function AddPDF417(rotate: Integer; xPos: Integer; yPos: Integer;
  xDots: Integer; yDots: Integer; columns: Integer; rows: Integer;
  eccLevel: Integer; data: ansistring): Integer;
begin
  Result := CPCL_AddPDF417(printer, rotate, xPos, yPos, xDots, yDots, columns,
    rows, eccLevel, data);
end;

function AddBox(xPos: Integer; yPos: Integer; endXPos: Integer;
  endYPos: Integer; thickness: Integer): Integer;
begin
  Result := CPCL_AddBox(printer, xPos, yPos, endXPos, endYPos, thickness);
end;

function AddLine(xPos: Integer; yPos: Integer; endXPos: Integer;
  endYPos: Integer; thickness: Integer): Integer;
begin
  Result := CPCL_AddLine(printer, xPos, yPos, endXPos, endYPos, thickness);
end;

function SetFontSize(width: Integer; height: Integer): Integer;
begin
  Result := CPCL_SetFontSize(printer, width, height);
end;

function SetDensity(density: Integer): Integer;
begin
  Result := CPCL_SetDensity(printer, density);
end;

function SetSpeed(speed: Integer): Integer;
begin
  Result := CPCL_SetSpeed(printer, speed);
end;

function SetTextSpacing(spacing: Integer): Integer;
begin
  Result := CPCL_SetTextSpacing(printer, spacing);
end;

function SetTextBold(bold: Integer): Integer;
begin
  Result := CPCL_SetTextBold(printer, bold);
end;

function SetTextUnderline(underline: Integer): Integer;
begin
  Result := CPCL_SetTextUnderline(printer, underline);
end;

function LabelPrint(): Integer;
begin
  Result := CPCL_Print(printer)
end;

function NextLabelPos(): Integer;
begin
  Result := CPCL_NextLabelPos(printer)
end;

function PreFeed(distance: Integer): Integer;
begin
  Result := CPCL_PreFeed(printer, distance);
end;

function PostFeed(distance: Integer): Integer;
begin
  Result := CPCL_PostFeed(printer, distance);
end;

end.
